==> igniteui-react-layouts-18.2.0.tgz: package/esm5/lib/igr-tool-action-group-header.js <==
import { __extends } from "tslib";
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionGroupHeader } from "./ToolActionGroupHeader";
import { brushToString, stringToBrush } from "igniteui-react-core";
var IgrToolActionGroupHeader = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolActionGroupHeader, _super);
    function IgrToolActionGroupHeader(props) {
        return _super.call(this, props) || this;
    }
    IgrToolActionGroupHeader.prototype.createImplementation = function () {
        return new ToolActionGroupHeader();
    };
    Object.defineProperty(IgrToolActionGroupHeader.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionGroupHeader.prototype, "actualBackIconColor", {
        /**
         * Gets the actual back icon color.
        */
        get: function () {
            return brushToString(this.i.fb);
        },
        set: function (v) {
            this.i.fb = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionGroupHeader.prototype, "backIconColor", {
        /**
         * Gets or sets the icon color for the back button.
        */
        get: function () {
            return brushToString(this.i.fc);
        },
        set: function (v) {
            this.i.fc = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrToolActionGroupHeader;
}(IgrToolAction));
export { IgrToolActionGroupHeader };

==> igniteui-react-layouts-18.6.1.tgz: package/esm5/lib/igr-tool-action-group-header.js <==
import { __extends } from "tslib";
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionGroupHeader } from "./ToolActionGroupHeader";
import { brushToString, stringToBrush } from "igniteui-react-core";
var IgrToolActionGroupHeader = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolActionGroupHeader, _super);
    function IgrToolActionGroupHeader(props) {
        return _super.call(this, props) || this;
    }
    IgrToolActionGroupHeader.prototype.createImplementation = function () {
        return new ToolActionGroupHeader();
    };
    Object.defineProperty(IgrToolActionGroupHeader.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionGroupHeader.prototype, "actualBackIconColor", {
        /**
         * Gets the actual back icon color.
        */
        get: function () {
            return brushToString(this.i.gf);
        },
        set: function (v) {
            this.i.gf = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionGroupHeader.prototype, "backIconColor", {
        /**
         * Gets or sets the icon color for the back button.
        */
        get: function () {
            return brushToString(this.i.gg);
        },
        set: function (v) {
            this.i.gg = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrToolActionGroupHeader;
}(IgrToolAction));
export { IgrToolActionGroupHeader };
